@@ -2,6 +2,9 @@
 # pylint: disable=undefined-variable
 """Module with data plugins to represent pseudo potentials."""
 from .pseudo import *
+from .psf import *
+from .psml import *
+from .psp8 import *
 from .upf import *
 
-__all__ = (pseudo.__all__ + upf.__all__)
+__all__ = (pseudo.__all__ + psf.__all__ + psml.__all__ + psp8.__all__ + upf.__all__)
