@@ -2,7 +2,10 @@
 # pylint: disable=undefined-variable
 """Module with group plugins to represent pseudo potential families."""
 from .pseudo import *
+from .psf import *
+from .psml import *
+from .psp8 import *
 from .sssp import *
 from .upf import *
 
-__all__ = (pseudo.__all__ + sssp.__all__ + upf.__all__)
+__all__ = (pseudo.__all__ + psf.__all__ + psml.__all__ + psp8.__all__ + sssp.__all__ + upf.__all__)
